@@ -21,8 +21,10 @@
 """
 Code for Test Specification Model Generation
 """
+import logging
 import os
 import re
+import typing
 import warnings
 from base64 import b64encode
 from collections import OrderedDict
@@ -193,15 +195,16 @@ def t_case_for_key(test_case_key: str) -> dict[str, Any]:
     return cached_testcase_resp
 
 
+@typing.no_type_check
 def download_and_rewrite_images(value: str) -> str:
     warnings.filterwarnings("ignore", category=MarkupResemblesLocatorWarning)
     soup = BeautifulSoup(value.encode("utf-8"), "html.parser")
     rest_location = urljoin(Config.JIRA_INSTANCE, "rest")
     for img in soup.find_all("img"):
-        # print(" - ", img)
-        try:
+        try:  # img["style"] before typing ..
             img_width = re.sub("[^0-9]", "", img["style"])
-        except Exception:
+        except Exception as w:
+            logging.log(logging.WARN, w)
             img_width = "150"
         img_url = urljoin(rest_location, img["src"])
         url_path = urlparse(img_url).path[1:]
@@ -231,8 +234,16 @@ def download_and_rewrite_images(value: str) -> str:
                             resp = requests.get(img_url)
                         resp.raise_for_status()
                     except requests.exceptions.HTTPError as err:
-                        Config.exeuction_errored = True
-                        errstr = str(err)
+                        # cloudfront is private smartbear will not allow access
+                        # so its not an error it's a feature
+                        if "cloudfront" in img_url:
+                            logging.log(
+                                logging.WARN, f"You can not access {img_url}"
+                            )
+                            errstr = "No access to cloudfront images."
+                        else:
+                            Config.exeuction_errored = True
+                            errstr = str(err)
                 if errstr is not None:
                     print(errstr)
                     # in order the final user can see where the problem is
@@ -350,6 +361,7 @@ def create_folders_and_files() -> None:
             pass
 
 
+@typing.no_type_check
 def rewrite_strong_to_subsection(content: str, extractable: list) -> str:
     """
     Extract specific "strong" elements and rewrite them to headings so
@@ -463,7 +475,14 @@ def get_rest_session() -> Session:
         return Config.THE_SESSION
 
     # initialize connection to Jira REST API
-    usr_pwd = Config.AUTH[0] + ":" + Config.AUTH[1]
+    if Config.AUTH and len(Config.AUTH) == 2:
+        usr_pwd = Config.AUTH[0] + ":" + Config.AUTH[1]
+    else:
+        logging.log(
+            logging.WARN,
+            "Did not get JIRA_USER and JIRA_PASSWORD in Config.AUTH",
+        )
+        usr_pwd = "NOUSER:NOPASS"
     connection_str = b64encode(usr_pwd.encode("ascii")).decode("ascii")
     headers: MutableMapping[str, str | bytes] = {
         "accept": "application/json",
